@@ -9,9 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 __all__ = [
     "hacks",
@@ -25,9 +23,9 @@ __all__ = [
 
 from os.path import join
 
-from .parsing import render_yaml, parse_yaml, validate_yaml
-from .linting import lint_all
 from . import hacks, validators
+from .linting import lint_all
+from .parsing import parse_yaml, render_yaml, validate_yaml
 
 
 def write_jsroot_compression_options(dynamic_dir):
