@@ -9,9 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 known_working_groups = [
     "B2CC",
