@@ -9,27 +9,18 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
-from collections import OrderedDict
-from os.path import relpath, isfile, join
 import re
-import yaml
+from collections import OrderedDict
+from os.path import isfile, join, relpath
+
 import jinja2
-from strictyaml import (
-    Any,
-    Bool,
-    Enum,
-    load,
-    Map,
-    MapPattern,
-    Optional,
-    Regex,
-    Seq,
-    Str,
-)
+import yaml
+from strictyaml import Any, Bool, Enum, Int, Map, MapPattern
+from strictyaml import Optional
+from strictyaml import Optional as Opt
+from strictyaml import Regex, Seq, Str, load
 
 from LbAPCommon import config
 
@@ -66,6 +57,11 @@ BASE_JOB_SCHEMA = {
     Optional("dddb_tag"): Regex(RE_DDDB_TAG),
     Optional("conddb_tag"): Regex(RE_CONDDB_TAG),
 }
+INPUT_SCHEMAS = {
+    "bk_query": Map({"bk_query": Str(), Opt("n_test_lfns"): Int()}),
+    "job_name": Map({"job_name": Str()}),
+    "prod_id": Map({"prod_id": Str()}),
+}
 DEFAULT_JOB_VALUES = {
     "automatically_configure": False,
     "turbo": False,
@@ -139,12 +135,24 @@ def parse_yaml(rendered_yaml):
             else:
                 production_schema[key] = value
 
-        data2.update(
-            load(
-                yaml.safe_dump({k: v}),
-                MapPattern(job_name_schema, Map(production_schema), minimum_keys=1),
-            ).data
+        data = load(
+            yaml.safe_dump({k: v}),
+            MapPattern(job_name_schema, Map(production_schema), minimum_keys=1),
         )
+        for input_key, input_schema in INPUT_SCHEMAS.items():
+            if input_key in data.data[k]["input"]:
+                data[k]["input"].revalidate(input_schema)
+                break
+        else:
+            raise ValueError(
+                (
+                    "Failed to find a valid schema for %s's input. "
+                    "Allowed values are: %s"
+                )
+                % (k, set(INPUT_SCHEMAS))
+            )
+
+        data2.update(data.data)
 
     return data2
 
