@@ -9,9 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 __all__ = [
     "match_output_filenames",
@@ -21,8 +19,8 @@ __all__ = [
     "explain_log",
 ]
 
-from os.path import basename
 import re
+from os.path import basename
 
 from lxml import etree
 
@@ -85,7 +83,14 @@ def match_output_filenames(filenames, output_filetypes, application_name, step_i
         for output_filetype in output_filetypes:
             if fn.upper().endswith(output_filetype):
                 if output_fns[output_filetype] is not None:
-                    raise NotImplementedError(fn, output_fns)
+                    raise NotImplementedError(
+                        (
+                            "Something is very wrong! Multiple files have been found "
+                            "that match {output_filetype} however files in the "
+                            "bookkeeping are case-insensitive. The following "
+                            "filenames were uploaded by the job: {filenames}"
+                        ).format(output_filetype=output_filetype, filenames=filenames)
+                    )
                 output_fns[output_filetype] = fn
 
     return xml_summary_fn, xml_bk_fn, log_fn, output_fns
