@@ -9,14 +9,13 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 from textwrap import dedent
 
 import pytest
 import strictyaml
+
 import LbAPCommon
 
 OPTIONAL_KEYS = [
